<h1>Python Package: utils-pandas</h1>

<b>Descrição:</b>
<p>
    Biblioteca Python com objetivo de criar funcionalidades adicionais para a Biblioteca pandas.
</p>

<hr>
<b>Links</b> <br>
<b>Pandas:</b> <a href="https://pypi.org/project/pandas/" target="_blank">https://pypi.org/project/pandas/</a> <br>


<hr>
<b>Instalação:</b>
<p>pip install utils-pandas</p>
<hr>
<hr>
<b>Doação:</b>
<p>Ajude o Projeto a continuar, qualquer doação é bem vinda</p>

<b>CHAVE PIX: </b> d51024a6-4320-4cb6-9241-b0a4d165dfd2 <br>
<b>PIX Copia e Cola: </b> <a href="00020126860014br.gov.bcb.pix0136d51024a6-4320-4cb6-9241-b0a4d165dfd20224Doacao para Projeto PiPY5204000053039865802BR5924Jonathas Henrique Miante6009Sao Paulo62100506Doacao630459B3"> Link </a> <br>
<b>QRCODE PIX: </b> <br> <img src="https://raw.githubusercontent.com/jmiante/relativedate/84840043692a8ddba11572b19379d7c9ad6381d2/site/img/pix.jpg" style="max-width: 300px;">
<hr>
<p><b>Nome: </b>Jonathas Henrique Miante - <b>Banco: </b>PicPay</p>

<hr>
<hr>

